[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# GATS
Implementation of GATS from the paper: "GATS: Gather-Attend-Scatter" in pytorch and zeta.


## Install
`pip install gats`

## Usage


# Citation
```bibtex
@misc{zolna2024gats,
    title={GATS: Gather-Attend-Scatter}, 
    author={Konrad Zolna and Serkan Cabi and Yutian Chen and Eric Lau and Claudio Fantacci and Jurgis Pasukonis and Jost Tobias Springenberg and Sergio Gomez Colmenarejo},
    year={2024},
    eprint={2401.08525},
    archivePrefix={arXiv},
    primaryClass={cs.AI}
}
```

# License
MIT



